django_turnit.templatetags package
==================================

.. automodule:: django_turnit.templatetags
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

django_turnit.templatetags.turnit_tags module
---------------------------------------------

.. automodule:: django_turnit.templatetags.turnit_tags
    :members:
    :undoc-members:
    :show-inheritance:


